export { default as default } from './actions.svelte.js';
export { default as l10n } from 'flatpickr_plus/dist/l10n';
import type { DateLimit, DateOption, Hook } from './types.js';
export type FlatpickrOptions = {
    allowInput?: boolean;
    allowInvalidPreload?: boolean;
    altFormat?: string;
    altInput?: boolean;
    altInputClass?: string;
    animate?: boolean;
    appendTo?: HTMLElement;
    ariaDateFormat?: string;
    autoFillDefaultTime?: boolean;
    clickOpens?: boolean;
    closeOnSelect?: boolean;
    conjunction?: string;
    dateFormat?: string;
    defaultDate?: DateOption | DateOption[];
    defaultHour?: number;
    defaultMinute?: number;
    defaultSeconds?: number;
    disable?: DateLimit<DateOption>[];
    disableMobile?: boolean;
    enable?: DateLimit<DateOption>[];
    enableSeconds?: boolean;
    enableTime?: boolean;
    errorHandler?: (e: Error) => void;
    formatDate?: (date: Date, format: string, locale: any) => string;
    getWeek?: (date: Date) => string | number;
    hourIncrement?: number;
    ignoredFocusElements?: HTMLElement[];
    inline?: boolean;
    isMonthPicker?: boolean;
    locale?: any | Partial<any>;
    maxDate?: DateOption;
    maxTime?: DateOption;
    minDate?: DateOption;
    minTime?: DateOption;
    minuteIncrement?: number;
    mode?: 'single' | 'multiple' | 'range' | 'time';
    monthSelectorType?: 'dropdown' | 'static';
    nextArrow?: string;
    noCalendar?: boolean;
    now?: DateOption;
    onChange?: Hook | Hook[];
    onClose?: Hook | Hook[];
    onDayCreate?: Hook | Hook[];
    onDestroy?: Hook | Hook[];
    onKeyDown?: Hook | Hook[];
    onMonthChange?: Hook | Hook[];
    onOpen?: Hook | Hook[];
    onParseConfig?: Hook | Hook[];
    onReady?: Hook | Hook[];
    onValueUpdate?: Hook | Hook[];
    onYearChange?: Hook | Hook[];
    onPreCalendarPosition?: Hook | Hook[];
    parseDate?: (date: string, format: string) => Date;
    plugins?: Plugin[];
    position?: 'auto' | 'above' | 'below' | 'auto left' | 'auto center' | 'auto right' | 'above left' | 'above center' | 'above right' | 'below left' | 'below center' | 'below right' | ((self: any, customElement: HTMLElement | undefined) => void);
    positionElement?: Element;
    prevArrow?: string;
    shorthandCurrentMonth?: boolean;
    shorthand?: boolean;
    static?: boolean;
    showMonths?: number;
    time_24hr?: boolean;
    weekNumbers?: boolean;
    wrap?: boolean;
    useLocaleYear?: boolean;
    resetMoveDefault?: boolean;
    resetToDefault?: boolean;
};
/**
 * Enum-like object defining available theme names
 * @enum {string}
 */
export declare const themeNames: {
    default: string;
    light: string;
    dark: string;
    materialBlue: string;
    materialGreen: string;
    materialRed: string;
    materialOrange: string;
    airbnb: string;
    confetti: string;
};
/**
 * Retrieves a CSS file for a given theme name.
 *
 * @param { string } themeName - The name of the theme to load
 * @returns { Promise < string | null >} The CSS content of the theme or null if not found
 *
 * @example
 * // Successful theme load
 * const darkTheme = await themes('dark');
 *
 * @example
 * // Theme not found
 * const missingTheme = await themes('nonexistent');
 * // Returns null
 */
export declare function themeChanger(themeName: any): Promise<any>;
export declare function currentTheme(): string;
